"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var common = require("./image-cache-it.common");
var image_cache_it_common_1 = require("./image-cache-it.common");
var fs = require("tns-core-modules/file-system");
var utils = require("tns-core-modules/utils/utils");
var types = require("tns-core-modules/utils/types");
var view_1 = require("tns-core-modules/ui/core/view");
var frame_1 = require("tns-core-modules/ui/frame");
var app = require("tns-core-modules/application");
var background_1 = require("tns-core-modules/ui/styling/background");
global.moduleMerge(common, exports);
var ImageCacheIt = (function (_super) {
    __extends(ImageCacheIt, _super);
    function ImageCacheIt() {
        return _super.call(this) || this;
    }
    ImageCacheIt.prototype.hasBorderWidth = function () {
        return this.borderTopWidth !== 0
            || this.borderRightWidth !== 0
            || this.borderBottomWidth !== 0
            || this.borderLeftWidth !== 0;
    };
    ImageCacheIt.prototype.hasBorderColor = function () {
        return !!this.borderTopColor || !!this.borderRightColor || !!this.borderBottomColor || !!this.borderLeftColor;
    };
    ImageCacheIt.prototype.hasUniformBorderColor = function () {
        return view_1.Color.equals(this.borderTopColor, this.borderRightColor) &&
            view_1.Color.equals(this.borderTopColor, this.borderBottomColor) &&
            view_1.Color.equals(this.borderTopColor, this.borderLeftColor);
    };
    ImageCacheIt.prototype.hasUniformBorderWidth = function () {
        return this.borderTopWidth === this.borderRightWidth &&
            this.borderTopWidth === this.borderBottomWidth &&
            this.borderTopWidth === this.borderLeftWidth;
    };
    ImageCacheIt.prototype.hasBorderRadius = function () {
        return this.borderTopLeftRadius > 0
            || this.borderTopRightRadius > 0
            || this.borderBottomRightRadius > 0
            || this.borderBottomLeftRadius > 0;
    };
    ImageCacheIt.prototype.hasUniformBorderRadius = function () {
        return this.borderTopLeftRadius === this.borderTopRightRadius &&
            this.borderTopLeftRadius === this.borderBottomRightRadius &&
            this.borderTopLeftRadius === this.borderBottomLeftRadius;
    };
    ImageCacheIt.prototype.hasUniformBorder = function () {
        return this.hasUniformBorderColor() &&
            this.hasUniformBorderWidth() &&
            this.hasUniformBorderRadius();
    };
    ImageCacheIt.prototype.getContext = function () {
        var context;
        if (frame_1.topmost()) {
            if (frame_1.topmost().android && frame_1.topmost().android.activity) {
                context = frame_1.topmost().android.activity;
            }
            else if (frame_1.topmost().currentPage && frame_1.topmost().currentPage.frame && frame_1.topmost().currentPage.frame.android && frame_1.topmost().currentPage.frame.android.activity) {
                context = frame_1.topmost().currentPage.frame.android.activity;
            }
        }
        if (!context) {
            context = this._context;
        }
        return context;
    };
    ImageCacheIt.prototype.getGlide = function () {
        if (!this._manager) {
            this._manager = com.bumptech.glide.Glide.with(this.getContext());
        }
        return this._manager;
    };
    ImageCacheIt.prototype.createNativeView = function () {
        return new android.widget.ImageView(this._context);
    };
    ImageCacheIt.prototype.initNativeView = function () {
        if (this.src) {
            var image = ImageCacheIt.getImage(this.src);
            this._builder = this.getGlide().load(image);
        }
        this.resetImage();
        if (this._builder) {
            this._builder.into(this.nativeView);
        }
    };
    ImageCacheIt.prototype[view_1.borderTopColorProperty.setNative] = function (color) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = new background_1.Background();
    };
    ImageCacheIt.prototype[view_1.borderRightColorProperty.setNative] = function (color) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = new background_1.Background();
    };
    ImageCacheIt.prototype[view_1.borderBottomColorProperty.setNative] = function (color) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = new background_1.Background();
    };
    ImageCacheIt.prototype[view_1.borderLeftColorProperty.setNative] = function (color) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = new background_1.Background();
    };
    ImageCacheIt.prototype[view_1.borderTopWidthProperty.setNative] = function (width) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = new background_1.Background();
    };
    ImageCacheIt.prototype[view_1.borderRightWidthProperty.setNative] = function (width) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = new background_1.Background();
    };
    ImageCacheIt.prototype[view_1.borderBottomWidthProperty.setNative] = function (width) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = new background_1.Background();
    };
    ImageCacheIt.prototype[view_1.borderLeftWidthProperty.setNative] = function (width) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = new background_1.Background();
    };
    ImageCacheIt.prototype[view_1.borderTopLeftRadiusProperty.setNative] = function (radius) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = new background_1.Background();
    };
    ImageCacheIt.prototype[view_1.borderTopRightRadiusProperty.setNative] = function (radius) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = new background_1.Background();
    };
    ImageCacheIt.prototype[view_1.borderBottomLeftRadiusProperty.setNative] = function (radius) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = new background_1.Background();
    };
    ImageCacheIt.prototype[view_1.borderBottomRightRadiusProperty.setNative] = function (radius) {
        this.setBorderAndRadius();
        this.style.backgroundInternal = new background_1.Background();
    };
    ImageCacheIt.prototype[image_cache_it_common_1.filterProperty.setNative] = function (filter) {
        this.filter = filter;
        this.resetImage(true);
    };
    ImageCacheIt.isNumber = function (value) {
        return typeof value === 'number';
    };
    ImageCacheIt.getResourceId = function (res) {
        if (res === void 0) { res = ''; }
        if (res.startsWith('res://')) {
            return utils.ad.resources.getDrawableId(res.replace('res://', ''));
        }
        return 0;
    };
    ImageCacheIt.prototype.setPlaceHolder = function () {
        if (this.placeHolder) {
            var placeholder = ImageCacheIt.getResourceId(this.placeHolder);
            if (placeholder > 0) {
                if (this._builder) {
                    this._builder.placeholder(placeholder);
                }
            }
        }
    };
    ImageCacheIt.prototype.setErrorHolder = function () {
        if (this.errorHolder) {
            var errorHolder = ImageCacheIt.getResourceId(this.errorHolder);
            if (errorHolder > 0) {
                if (this._builder) {
                    this._builder.error(errorHolder);
                }
            }
        }
    };
    ImageCacheIt.prototype[common.srcProperty.getDefault] = function () {
        return undefined;
    };
    ImageCacheIt.prototype[common.srcProperty.setNative] = function (src) {
        var image = ImageCacheIt.getImage(src);
        this._builder = this.getGlide().load(image);
        this.resetImage();
        this._builder.into(this.nativeView);
        return src;
    };
    ImageCacheIt.prototype[common.decodedWidthProperty.setNative] = function (width) {
        this.resetImage(true);
    };
    ImageCacheIt.prototype[common.decodedHeightProperty.setNative] = function (height) {
        this.resetImage(true);
    };
    ImageCacheIt.getImage = function (src) {
        var nativeImage;
        if (types.isNullOrUndefined(src)) {
            return src;
        }
        if (src.substr(0, 1) === '/') {
            nativeImage = new java.io.File(src);
        }
        else if (src.startsWith('~/')) {
            nativeImage = new java.io.File(fs.path.join(fs.knownFolders.currentApp().path, src.replace('~/', '')));
        }
        else if (src.startsWith('http')) {
            nativeImage = src;
        }
        else if (src.startsWith('res://')) {
            nativeImage = java.lang.Integer.valueOf(utils.ad.resources.getDrawableId(src.replace('res://', '')));
        }
        return nativeImage;
    };
    ImageCacheIt.prototype[common.stretchProperty.getDefault] = function () {
        return 'aspectFit';
    };
    ImageCacheIt.prototype[common.stretchProperty.setNative] = function (value) {
        if (!this._builder)
            return value;
        this.resetImage(true);
        return value;
    };
    ImageCacheIt.getItem = function (src) {
        return new Promise(function (resolve, reject) {
            com.bumptech.glide.Glide.with(app.android.context)
                .downloadOnly()
                .addListener(new com.bumptech.glide.request.RequestListener({
                onLoadFailed: function (error, param1, target, param3) {
                    reject();
                    return false;
                },
                onResourceReady: function (param0, param1, target, dataSource, param4) {
                    resolve();
                    return false;
                }
            }));
        });
    };
    ImageCacheIt.deleteItem = function (src) {
        return new Promise(function (resolve, reject) {
        });
    };
    ImageCacheIt.fetchItem = function (src) {
        return new Promise(function (resolve, reject) {
        });
    };
    ImageCacheIt.prototype.setBorderAndRadius = function () {
        if (!this._builder)
            return null;
        var ColoredRoundedCornerBorders = com.github.triniwiz.imagecacheit.ColoredRoundedCornerBorders;
        var list = new java.util.ArrayList();
        if (this.hasUniformBorder() && this.hasBorderColor()) {
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderTopLeftRadius), 0, ColoredRoundedCornerBorders.CornerType.ALL, this.style.borderTopColor ? this.style.borderTopColor.android : android.graphics.Color.BLACK, view_1.layout.toDevicePixels(this.style.borderTopWidth), -1, -1));
        }
        else if (this.hasBorderColor()) {
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderTopRightRadius), 0, ColoredRoundedCornerBorders.CornerType.BORDER_TOP, this.style.borderTopColor ? this.style.borderTopColor.android : android.graphics.Color.BLACK, view_1.layout.toDevicePixels(this.style.borderTopWidth), -1, -1));
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderBottomRightRadius), 0, ColoredRoundedCornerBorders.CornerType.BORDER_RIGHT, this.style.borderRightColor ? this.style.borderRightColor.android : android.graphics.Color.BLACK, view_1.layout.toDevicePixels(this.style.borderRightWidth), -1, -1));
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderBottomLeftRadius), 0, ColoredRoundedCornerBorders.CornerType.BORDER_BOTTOM, this.style.borderBottomColor ? this.style.borderBottomColor.android : android.graphics.Color.BLACK, view_1.layout.toDevicePixels(this.style.borderBottomWidth), -1, -1));
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderTopLeftRadius), 0, ColoredRoundedCornerBorders.CornerType.BORDER_LEFT, this.style.borderTopColor ? this.style.borderTopColor.android : android.graphics.Color.BLACK, view_1.layout.toDevicePixels(this.style.borderTopWidth), -1, -1));
        }
        else {
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderTopRightRadius), 0, ColoredRoundedCornerBorders.CornerType.TOP_RIGHT, 0, 0, -1, -1));
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderBottomRightRadius), 0, ColoredRoundedCornerBorders.CornerType.BOTTOM_RIGHT, 0, 0, -1, -1));
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderBottomLeftRadius), 0, ColoredRoundedCornerBorders.CornerType.BOTTOM_LEFT, 0, 0, -1, -1));
            list.add(new ColoredRoundedCornerBorders(view_1.layout.toDevicePixels(this.style.borderTopLeftRadius), 0, ColoredRoundedCornerBorders.CornerType.TOP_LEFT, 0, 0, -1, -1));
        }
        return list;
    };
    ImageCacheIt.prototype.setAspectResize = function () {
        var Target = com.bumptech.glide.request.target.Target;
        if (ImageCacheIt.isNumber(this.decodedWidth) && Number.isNaN(this.decodedHeight)) {
            this._builder.override(view_1.layout.toDevicePixels(this.decodedWidth), Target.SIZE_ORIGINAL);
        }
        if (ImageCacheIt.isNumber(this.decodedHeight) && Number.isNaN(this.decodedWidth)) {
            this._builder.override(Target.SIZE_ORIGINAL, view_1.layout.toDevicePixels(this.decodedHeight));
        }
        if (ImageCacheIt.isNumber(this.decodedHeight) && ImageCacheIt.isNumber(this.decodedWidth)) {
            this._builder.override(view_1.layout.toDevicePixels(this.decodedWidth), view_1.layout.toDevicePixels(this.decodedHeight));
        }
    };
    ImageCacheIt.prototype.resetImage = function (reload) {
        if (reload === void 0) { reload = false; }
        if (!this._builder)
            return;
        var transformations = new java.util.ArrayList();
        var MultiTransformation = com.bumptech.glide.load.MultiTransformation;
        switch (this.stretch) {
            case 'aspectFit':
                transformations.add(new com.bumptech.glide.load.resource.bitmap.FitCenter());
                break;
            case 'aspectFill':
                transformations.add(new com.bumptech.glide.load.resource.bitmap.CenterCrop());
                break;
            case 'fill':
                this.nativeView.setScaleType(android.widget.ImageView.ScaleType.FIT_XY);
                break;
            case 'none':
            default:
                this.nativeView.setScaleType(android.widget.ImageView.ScaleType.MATRIX);
                break;
        }
        var getValue = function (value) {
            return value.substring(value.indexOf('(') + 1, value.indexOf(')'));
        };
        if (this.filter) {
            var filters = this.filter ? this.filter.split(' ') : [];
            filters.forEach(function (filter) {
                var value = getValue(filter);
                if (filter.indexOf('blur') > -1) {
                    var width = -1;
                    if (value.indexOf('%') === -1) {
                        value = view_1.Length.parse(value);
                        if (value.unit === 'px') {
                            width = value.value;
                        }
                        else if (value.unit === 'dip') {
                            width = view_1.layout.toDevicePixels(value.unit);
                        }
                        if (width > -1) {
                            transformations.add(new jp.wasabeef.glide.transformations.BlurTransformation(width));
                        }
                    }
                }
                else if (filter.indexOf('contrast') > -1) {
                    if (value.indexOf('%')) {
                        var contrast = parseFloat(value.replace('%', '')) / 100;
                        transformations.add(new jp.wasabeef.glide.transformations.gpu.ContrastFilterTransformation(new java.lang.Float(contrast).intValue()));
                    }
                }
                else if (filter.indexOf('brightness') > -1) {
                    if (value.indexOf('%')) {
                        var brightness = parseFloat(value.replace('%', '')) / 100;
                        if (brightness >= 0 && brightness < 1) {
                            brightness = -1 + brightness;
                        }
                        transformations.add(new jp.wasabeef.glide.transformations.gpu.BrightnessFilterTransformation(new java.lang.Float(brightness).intValue()));
                    }
                }
                else if (filter.indexOf('grayscale') > -1 || filter.indexOf('greyscale') > -1) {
                    transformations.add(new jp.wasabeef.glide.transformations.GrayscaleTransformation());
                }
                else if (filter.indexOf('invert') > -1) {
                    transformations.add(new jp.wasabeef.glide.transformations.gpu.InvertFilterTransformation());
                }
                else if (filter.indexOf('sepia') > -1) {
                    var sepia = parseFloat(value.replace('%', '')) / 100;
                    transformations.add(new jp.wasabeef.glide.transformations.gpu.SepiaFilterTransformation(new java.lang.Float(sepia).intValue()));
                }
            });
        }
        if (reload) {
            var image = ImageCacheIt.getImage(this.src);
            this._builder = this.getGlide().load(image);
            this.setPlaceHolder();
            this.setErrorHolder();
        }
        var borderTransformations = this.setBorderAndRadius();
        if (borderTransformations.size() > 0) {
            var borderArray = borderTransformations.toArray();
            var borderArrayLength = borderArray.length;
            for (var i = 0; i < borderArrayLength; i++) {
                transformations.add(borderArray[i]);
            }
        }
        if (transformations.size() > 0) {
            var array = transformations.toArray();
            var count = array.length;
            var transformationArray = Array.create('com.bumptech.glide.load.Transformation', count);
            for (var i = 0; i < count; i++) {
                transformationArray[i] = array[i];
            }
            this._builder.apply(com.bumptech.glide.request.RequestOptions.bitmapTransform(new MultiTransformation(transformationArray)));
        }
        this.setAspectResize();
    };
    return ImageCacheIt;
}(image_cache_it_common_1.ImageCacheItBase));
exports.ImageCacheIt = ImageCacheIt;
//# sourceMappingURL=image-cache-it.android.js.map